==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkGeoSphereTransform.java <==
// java wrapper for vtkGeoSphereTransform object
//

package vtk;
import vtk.*;

public class vtkGeoSphereTransform extends vtkAbstractTransform
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Inverse_2();
  public void Inverse()
    { Inverse_2(); }

  private native void InternalTransformPoint_3(double id0[],double id1[]);
  public void InternalTransformPoint(double id0[],double id1[])
    { InternalTransformPoint_3(id0,id1); }

  private native long MakeTransform_4();
  public vtkAbstractTransform MakeTransform() {
    long temp = MakeTransform_4();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetToRectangular_5(boolean id0);
  public void SetToRectangular(boolean id0)
    { SetToRectangular_5(id0); }

  private native boolean GetToRectangular_6();
  public boolean GetToRectangular()
    { return GetToRectangular_6(); }

  private native void ToRectangularOn_7();
  public void ToRectangularOn()
    { ToRectangularOn_7(); }

  private native void ToRectangularOff_8();
  public void ToRectangularOff()
    { ToRectangularOff_8(); }

  private native void SetBaseAltitude_9(double id0);
  public void SetBaseAltitude(double id0)
    { SetBaseAltitude_9(id0); }

  private native double GetBaseAltitude_10();
  public double GetBaseAltitude()
    { return GetBaseAltitude_10(); }

  public vtkGeoSphereTransform() { super(); }

  public vtkGeoSphereTransform(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-3-aarch64.pkg.tar.xz: vtk/vtkGeoSphereTransform.java <==
// java wrapper for vtkGeoSphereTransform object
//

package vtk;
import vtk.*;

public class vtkGeoSphereTransform extends vtkAbstractTransform
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Inverse_2();
  public void Inverse()
    { Inverse_2(); }

  private native void InternalTransformPoint_3(double id0[],double id1[]);
  public void InternalTransformPoint(double id0[],double id1[])
    { InternalTransformPoint_3(id0,id1); }

  private native long MakeTransform_4();
  public vtkAbstractTransform MakeTransform() {
    long temp = MakeTransform_4();

    if (temp == 0) return null;
    return (vtkAbstractTransform)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetToRectangular_5(boolean id0);
  public void SetToRectangular(boolean id0)
    { SetToRectangular_5(id0); }

  private native boolean GetToRectangular_6();
  public boolean GetToRectangular()
    { return GetToRectangular_6(); }

  private native void ToRectangularOn_7();
  public void ToRectangularOn()
    { ToRectangularOn_7(); }

  private native void ToRectangularOff_8();
  public void ToRectangularOff()
    { ToRectangularOff_8(); }

  private native void SetBaseAltitude_9(double id0);
  public void SetBaseAltitude(double id0)
    { SetBaseAltitude_9(id0); }

  private native double GetBaseAltitude_10();
  public double GetBaseAltitude()
    { return GetBaseAltitude_10(); }

  public vtkGeoSphereTransform() { super(); }

  public vtkGeoSphereTransform(long id) { super(id); }
  public native long   VTKInit();

}
